@@ -21,7 +21,7 @@ The other feature is simply to
 
 """
 import signal
-from itertools import izip, repeat
+from itertools import izip
 
 __all__ = ['pool', 'pmap']
 
@@ -77,11 +77,16 @@ def pmap(f, iterable, n=None, dummy=False, p=None):
       p: existing pool to re-use
     """
 
-    # just create repeated func, so we can /apply/ it across the
-    # iterable via the func_star function above
-
     if p is None:
-        p = pool(n, dummy)
-    assert hasattr(p, 'imap')
+        po = pool(n, dummy)
+    else:
+        po = p
+    assert hasattr(po, 'imap')
     f = _func_star(f)
-    return p.imap(f, iterable)
+    for r in po.imap(f, iterable):
+        yield r
+
+    # explicitly clean up created pool
+    if p is None:
+        po.terminate()
+        po.close()
